@@ -2,8 +2,7 @@
 // Enable support for syslinux's com32 images.
 //#define IMAGE_COMBOOT
 
-// Enable support for FTP and HTTPS downloads.
-#define DOWNLOAD_PROTO_FTP
+// Enable HTTPS downloads
 #define DOWNLOAD_PROTO_HTTPS
 
 // Disable iSCSI, AoE, Infiniband SCSI RDMA protocol and FibreChannel
